package com.huifu.jh.core.util;

import com.huifu.jh.core.exception.GcbPayException;
import com.huifu.jh.core.util.dto.GcbPayConstants;
import com.sun.org.apache.xerces.internal.parsers.DOMParser;
import org.w3c.dom.Document;
import org.xml.sax.InputSource;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.StringWriter;

/**
 * @author fang.wei
 * @Description Xml工具类
 * @createTime 2021年10月19日 15:41:00
 */
public class XmlUtils {

    /**
     * 对象转换XML
     * @param o
     * @return
     * @throws JAXBException
     */
    public static String toXml(Object o) throws JAXBException {
        JAXBContext context = JAXBContext.newInstance(o.getClass());
        Marshaller marshaller = context.createMarshaller();
        marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, true);
        marshaller.setProperty(Marshaller.JAXB_ENCODING, GcbPayConstants.ENCODING);
        StringWriter writer = new StringWriter();
        marshaller.marshal(o, writer);
        return writer.toString();
    }

    /**
     * XML转对象
     * @param xml
     * @param clazz
     * @param <T>
     * @return
     * @throws Exception
     */
    public static <T> T toBean(String xml, Class<T> clazz) throws Exception {
        JAXBContext context = JAXBContext.newInstance(clazz);
        Unmarshaller unmarshaller = context.createUnmarshaller();
        Object object = unmarshaller.unmarshal(new ByteArrayInputStream(xml.getBytes(GcbPayConstants.ENCODING)));
        return (T) object;
    }

    /**
     * xml转Doc对象
     * @param xml
     * @return
     * @throws GcbPayException
     */
    public static Document toDocument(String xml) throws GcbPayException {
        try {
            DOMParser parser = new DOMParser();
            parser.parse(new InputSource(new ByteArrayInputStream(xml.getBytes(GcbPayConstants.ENCODING))));
            return parser.getDocument();
        } catch (Exception e) {
            throw new GcbPayException("xml request transform error", e);
        }
    }

    /**
     * doc转xml
     * @param doc
     * @return
     */
    public static String toXml(Document doc) throws GcbPayException {
        try {
            TransformerFactory factory = TransformerFactory.newInstance();
            Transformer transformer = factory.newTransformer();
            transformer.setOutputProperty("encoding", GcbPayConstants.ENCODING);

            ByteArrayOutputStream os = new ByteArrayOutputStream();
            transformer.transform(new DOMSource(doc), new StreamResult(os));
            return os.toString(GcbPayConstants.ENCODING);
        } catch (Exception e) {
            throw new GcbPayException("xml request transform error", e);
        }
    }


}