package com.huifu.jh.payout.model;

import com.alibaba.fastjson.JSON;
import com.huifu.jh.core.model.GcbPayResponse;

import java.util.List;

/**
 * @author fang.wei
 * @Description 商户代发响应
 * @createTime 2021年10月20日 12:32:00
 */
public class GcbAgcyPaymentApplyResponse extends GcbPayResponse {

    private static final String STATUS_SUCCESS = "1";
    private static final String STATUS_FAILURE = "2";

    /**
     * 商户号
     * 会员账号，由我司提供的商户号+01，共13位数字
     */
    private String merchantId;

    /**
     * 虚拟终端号
     * 汇付给的虚拟终端号
     */
    private String terminalId;

    /**
     * 产品类型
     * 固定为：JH
     */
    private String productType = "JH";

    /**
     * 版本号 当前版本：1.0
     */
    private String version = "1.0";

    /**
     * 交易类别
     * 100040：代发申请
     */
    private String trxType = "100040";

    /**
     * 代发批次号
     * 商户系统中唯一性ID
     */
    private String batchNo;

    /**
     * 请求时间
     * 格式：yyyyMMddHHmmss
     * 例如：20161117020101
     */
    private String requestTime;

    /**
     * 币种
     * 默认CNY
     */
    private String payCur = "CNY";

    /**
     * 总笔数
     */
    private String payTotalCnt;

    /**
     * 总金额
     * 本次请求的总金额，格式为实际金额扩大100倍提交。
     * 如10000,表示100元
     */
    private String payTotalAmt;

    /**
     * 用途
     */
    private String purpose;

    /**
     * 扩展字段1
     */
    private String ext1;

    /**
     * 扩展字段2
     */
    private String ext2;

    /**
     * 结果通知地址
     */
    private String resultUrl;

    /**
     * 状态
     * 1:校验处理成功
     * 2:校验处理失败
     */
    private String status;

    /**
     * 错误码
     */
    private String errorCode;

    /**
     * 错误描述
     */
    private String errorMsg;

    /**
     * 返回明细
     */
    private List<GcbAgcyPaymentApplyResponseDetail> details;

    public String getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(String merchantId) {
        this.merchantId = merchantId;
    }

    public String getTerminalId() {
        return terminalId;
    }

    public void setTerminalId(String terminalId) {
        this.terminalId = terminalId;
    }

    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getTrxType() {
        return trxType;
    }

    public void setTrxType(String trxType) {
        this.trxType = trxType;
    }

    public String getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(String batchNo) {
        this.batchNo = batchNo;
    }

    public String getRequestTime() {
        return requestTime;
    }

    public void setRequestTime(String requestTime) {
        this.requestTime = requestTime;
    }

    public String getPayCur() {
        return payCur;
    }

    public void setPayCur(String payCur) {
        this.payCur = payCur;
    }

    public String getPayTotalCnt() {
        return payTotalCnt;
    }

    public void setPayTotalCnt(String payTotalCnt) {
        this.payTotalCnt = payTotalCnt;
    }

    public String getPayTotalAmt() {
        return payTotalAmt;
    }

    public void setPayTotalAmt(String payTotalAmt) {
        this.payTotalAmt = payTotalAmt;
    }

    public String getPurpose() {
        return purpose;
    }

    public void setPurpose(String purpose) {
        this.purpose = purpose;
    }

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getResultUrl() {
        return resultUrl;
    }

    public void setResultUrl(String resultUrl) {
        this.resultUrl = resultUrl;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getErrorCode() {
        return errorCode;
    }

    public void setErrorCode(String errorCode) {
        this.errorCode = errorCode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public List<GcbAgcyPaymentApplyResponseDetail> getDetails() {
        return details;
    }

    public void setDetails(List<GcbAgcyPaymentApplyResponseDetail> details) {
        this.details = details;
    }

    /**
     * 结果非明确失败，建议调用查询接口反查
     * @return
     */
    public PayoutRespStatus getRespStatus() {
        if (!isHttpStatusSuccess()) {
            return PayoutRespStatus.UNKNOWN;
        }

        if (STATUS_SUCCESS.equals(status)) {
            return PayoutRespStatus.SUCCESS;
        }

        if (STATUS_FAILURE.equals(status)) {
            return PayoutRespStatus.FAILURE;
        }

        return PayoutRespStatus.UNKNOWN;
    }

    @Override
    public String toString() {
        return "GcbAgcyPaymentApplyResponse{" +
                "merchantId='" + merchantId + '\'' +
                ", terminalId='" + terminalId + '\'' +
                ", productType='" + productType + '\'' +
                ", version='" + version + '\'' +
                ", trxType='" + trxType + '\'' +
                ", batchNo='" + batchNo + '\'' +
                ", requestTime='" + requestTime + '\'' +
                ", payCur='" + payCur + '\'' +
                ", payTotalCnt='" + payTotalCnt + '\'' +
                ", payTotalAmt='" + payTotalAmt + '\'' +
                ", purpose='" + purpose + '\'' +
                ", ext1='" + ext1 + '\'' +
                ", ext2='" + ext2 + '\'' +
                ", resultUrl='" + resultUrl + '\'' +
                ", status='" + status + '\'' +
                ", errorCode='" + errorCode + '\'' +
                ", errorMsg='" + errorMsg + '\'' +
                ", details=" + JSON.toJSONString(details) +
                '}';
    }
}