package com.huifu.jh.payout.model;

import com.huifu.jh.core.model.ParamRequest;
import org.apache.commons.lang.StringUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author fang.wei
 * @Description 用户提现请求
 * @createTime 2021年10月27日 14:12:00
 */
public class GcbUserAgcyPaymentApplyRequest implements ParamRequest<GcbUserAgcyPaymentApplyResponse> {

    /**
     * 网关版本 固定值：1
     * 必填
     */
    private String version = "1";

    /**
     * 签名类型 固定值：4。RSA加签
     * 必填
     */
    private String signType = "4";

    /**
     * 请求流水号 商户系统中唯一性ID
     * 必填
     */
    private String requestId;

    /**
     * 请求时间 yyyyMMddHHmmss
     * 必填
     */
    private String requestTime;

    /**
     * 请求会员号 会员账号，由我司提供的商户号+01，共13位数字
     * 必填
     */
    private String merchantAcctId;

    /**
     * 终端号 由我司提供
     * 必填
     */
    private String terminalId;

    /**
     * 提现批次号 商户系统中唯一标识该笔批次
     * 必填
     */
    private String batchNo;

    /**
     * 付款币种 默认CNY
     * 必填
     */
    private String payCur = "CNY";

    /**
     * 总笔数
     * 必填
     */
    private String payTCnt;

    /**
     * 总金额 单位分
     * 必填
     */
    private String payTAmt;

    /**
     * 是否忽略错误行 1：不忽略 2：忽略
     * 必填
     */
    private String ignoreFlag;

    /**
     * 用途 请从如下值中选一种填入：1. 销售结算款 2. 佣金/工资
     * 必填
     */
    private String purpose;

    /**
     * 扩展字段1
     */
    private String ext1;

    /**
     * 扩展字段2
     */
    private String ext2;

    /**
     * 结果通知地址
     * 必填
     */
    private String noticeUrl;

    /**
     * 实时部分结果通知地址2 当商户需要实时通知时传输
     */
    private String realTimeNoticeUrl;

    /**
     * 提现明细
     * 必填
     */
    private List<GcbUserAgcyPaymentApplyRequestDetail> details;

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getSignType() {
        return signType;
    }

    public void setSignType(String signType) {
        this.signType = signType;
    }

    public String getRequestId() {
        return requestId;
    }

    public void setRequestId(String requestId) {
        this.requestId = requestId;
    }

    public String getRequestTime() {
        return requestTime;
    }

    public void setRequestTime(String requestTime) {
        this.requestTime = requestTime;
    }

    public String getMerchantAcctId() {
        return merchantAcctId;
    }

    public void setMerchantAcctId(String merchantAcctId) {
        this.merchantAcctId = merchantAcctId;
    }

    public String getTerminalId() {
        return terminalId;
    }

    public void setTerminalId(String terminalId) {
        this.terminalId = terminalId;
    }

    public String getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(String batchNo) {
        this.batchNo = batchNo;
    }

    public String getPayCur() {
        return payCur;
    }

    public void setPayCur(String payCur) {
        this.payCur = payCur;
    }

    public String getPayTCnt() {
        return payTCnt;
    }

    public void setPayTCnt(String payTCnt) {
        this.payTCnt = payTCnt;
    }

    public String getPayTAmt() {
        return payTAmt;
    }

    public void setPayTAmt(String payTAmt) {
        this.payTAmt = payTAmt;
    }

    public String getIgnoreFlag() {
        return ignoreFlag;
    }

    public void setIgnoreFlag(String ignoreFlag) {
        this.ignoreFlag = ignoreFlag;
    }

    public String getPurpose() {
        return purpose;
    }

    public void setPurpose(String purpose) {
        this.purpose = purpose;
    }

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getNoticeUrl() {
        return noticeUrl;
    }

    public void setNoticeUrl(String noticeUrl) {
        this.noticeUrl = noticeUrl;
    }

    public String getRealTimeNoticeUrl() {
        return realTimeNoticeUrl;
    }

    public void setRealTimeNoticeUrl(String realTimeNoticeUrl) {
        this.realTimeNoticeUrl = realTimeNoticeUrl;
    }

    public List<GcbUserAgcyPaymentApplyRequestDetail> getDetails() {
        return details;
    }

    public void setDetails(List<GcbUserAgcyPaymentApplyRequestDetail> details) {
        this.details = details;
    }

    @Override
    public String getMerchantId() {
        return merchantAcctId;
    }

    @Override
    public Class<GcbUserAgcyPaymentApplyResponse> getResponseClass() {
        return GcbUserAgcyPaymentApplyResponse.class;
    }

    @Override
    public String[] getSignParamNames() {
        return new String[] {"batchNo","ignoreFlag","merchantAcctId","noticeUrl","payCur","payTAmt","payTCnt","requestId","requestTime","signType","terminalId","version"};
    }

    @Override
    public Map<String, String> getRequestData() {
        Map<String, String> requestData = new HashMap<>();
        requestData.put("version", version);
        requestData.put("signType", signType);
        requestData.put("requestId", requestId);
        requestData.put("requestTime", requestTime);
        requestData.put("merchantAcctId", merchantAcctId);
        requestData.put("terminalId", terminalId);
        requestData.put("batchNo", batchNo);
        requestData.put("payCur", payCur);
        requestData.put("payTCnt", payTCnt);
        requestData.put("payTAmt", payTAmt);
        requestData.put("ignoreFlag", ignoreFlag);
        requestData.put("purpose", purpose);
        requestData.put("ext1", ext1);
        requestData.put("ext2", ext2);
        requestData.put("noticeUrl", noticeUrl);
        requestData.put("realTimeNoticeUrl", realTimeNoticeUrl);
        requestData.put("details", convertDetails(details));
        return requestData;
    }

    private String convertDetails(List<GcbUserAgcyPaymentApplyRequestDetail> details) {
        if (details == null || details.isEmpty()) {
            return null;
        }

        StringBuffer sb = new StringBuffer();
        int size = details.size();
        for (int i=0; i<size; i++) {
            GcbUserAgcyPaymentApplyRequestDetail detail = details.get(i);
            sb.append(trim(detail.getRemitNo())).append("|")
                    .append(trim(detail.getAmt())).append("|")
                    .append(trim(detail.getBankId())).append("|")
                    .append(trim(detail.getAcctType())).append("|")
                    .append(trim(detail.getRemitType())).append("|")
                    .append(trim(detail.getAcctNo())).append("|")
                    .append(trim(detail.getPayeeName())).append("|")
                    .append(trim(detail.getIdType())).append("|")
                    .append(trim(detail.getIdNo())).append("|")
                    .append(trim(detail.getProvince())).append("|")
                    .append(trim(detail.getCity())).append("|")
                    .append(trim(detail.getBranchBankName())).append("|")
                    .append(trim(detail.getPurpose())).append("|")
                    .append(trim(detail.getRefNo())).append("|")
                    .append(trim(detail.getExt1())).append("|")
                    .append(trim(detail.getExt2())).append("|")
                    .append(trim(detail.getUserId())).append("|")
                    .append(trim(detail.getCnapsCode())).append("|")
                    .append(trim(detail.getRemark()));

            if (i < (size - 1)) {
                sb.append(";");
            }
        }

        return sb.toString();
    }

    private String trim(String val) {
        if (StringUtils.isBlank(val)) {
            return StringUtils.EMPTY;
        }

        return val.trim();
    }

}