package com.huifu.jh.payout.model;

import com.huifu.jh.core.model.ParamResponse;
import org.apache.commons.lang.StringUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * @author fang.wei
 * @Description 用户提现请求响应
 * @createTime 2021年10月27日 14:12:00
 */
public class GcbUserAgcyPaymentApplyResponse extends ParamResponse {
    private static final String SUCCESS = "1";

    /**
     * 网关版本 固定值：1
     * 必填
     */
    private String version = "1";

    /**
     * 签名类型 固定值：4。RSA加签
     * 必填
     */
    private String signType = "4";

    /**
     * 请求流水号 商户系统中唯一性ID
     * 必填
     */
    private String requestId;

    /**
     * 请求时间 yyyyMMddHHmmss
     * 必填
     */
    private String requestTime;

    /**
     * 请求会员号 会员账号，由我司提供的商户号+01，共13位数字
     * 必填
     */
    private String merchantAcctId;

    /**
     * 终端号 由我司提供
     * 必填
     */
    private String terminalId;

    /**
     * 提现批次号 商户系统中唯一标识该笔批次
     * 必填
     */
    private String batchNo;

    /**
     * 付款币种 默认CNY
     * 必填
     */
    private String payCur;

    /**
     * 总笔数
     * 必填
     */
    private String payTCnt;

    /**
     * 总金额 单位分
     * 必填
     */
    private String payTAmt;

    /**
     * 是否忽略错误行 1：不忽略 2：忽略
     * 必填
     */
    private String ignoreFlag;

    /**
     * 用途 请从如下值中选一种填入：1. 销售结算款 2. 佣金/工资
     * 必填
     */
    private String purpose;

    /**
     * 扩展字段1
     */
    private String ext1;

    /**
     * 扩展字段2
     */
    private String ext2;

    /**
     * 结果通知地址
     * 必填
     */
    private String noticeUrl;

    /**
     * 实时部分结果通知地址2 当商户需要实时通知时传输
     */
    private String realTimeNoticeUrl;

    /**
     * 提现明细
     * 存在错误明细时返回
     */
    private String details;

    /**
     * 状态
     * 1:全部接收成功
     * 2:全部接收失败
     * 3:部分接收成功（当且仅当ignoreFlag=2时返回）
     */
    private String status;

    /**
     * 错误码
     * 格式校验未通过时返回该字段
     */
    private String errorCode;

    /**
     * 错误描述
     * 格式校验未通过时返回该字段
     */
    private String errorMsg;

    @Override
    public boolean needCheckSign() {
        return true;
    }

    @Override
    public String[] getSignParamNames() {
        return new String[] {"batchNo","errorCode","errorMsg","ignoreFlag","merchantAcctId","noticeUrl","payCur","payTAmt","payTCnt","requestId","requestTime","signType","status","terminalId","version"};
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getSignType() {
        return signType;
    }

    public void setSignType(String signType) {
        this.signType = signType;
    }

    public String getRequestId() {
        return requestId;
    }

    public void setRequestId(String requestId) {
        this.requestId = requestId;
    }

    public String getRequestTime() {
        return requestTime;
    }

    public void setRequestTime(String requestTime) {
        this.requestTime = requestTime;
    }

    public String getMerchantAcctId() {
        return merchantAcctId;
    }

    public void setMerchantAcctId(String merchantAcctId) {
        this.merchantAcctId = merchantAcctId;
    }

    public String getTerminalId() {
        return terminalId;
    }

    public void setTerminalId(String terminalId) {
        this.terminalId = terminalId;
    }

    public String getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(String batchNo) {
        this.batchNo = batchNo;
    }

    public String getPayCur() {
        return payCur;
    }

    public void setPayCur(String payCur) {
        this.payCur = payCur;
    }

    public String getPayTCnt() {
        return payTCnt;
    }

    public void setPayTCnt(String payTCnt) {
        this.payTCnt = payTCnt;
    }

    public String getPayTAmt() {
        return payTAmt;
    }

    public void setPayTAmt(String payTAmt) {
        this.payTAmt = payTAmt;
    }

    public String getIgnoreFlag() {
        return ignoreFlag;
    }

    public void setIgnoreFlag(String ignoreFlag) {
        this.ignoreFlag = ignoreFlag;
    }

    public String getPurpose() {
        return purpose;
    }

    public void setPurpose(String purpose) {
        this.purpose = purpose;
    }

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getNoticeUrl() {
        return noticeUrl;
    }

    public void setNoticeUrl(String noticeUrl) {
        this.noticeUrl = noticeUrl;
    }

    public String getRealTimeNoticeUrl() {
        return realTimeNoticeUrl;
    }

    public void setRealTimeNoticeUrl(String realTimeNoticeUrl) {
        this.realTimeNoticeUrl = realTimeNoticeUrl;
    }

    public String getDetails() {
        return details;
    }

    public void setDetails(String details) {
        this.details = details;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getErrorCode() {
        return errorCode;
    }

    public void setErrorCode(String errorCode) {
        this.errorCode = errorCode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 获取明细列表
     * @return
     */
    public List<GcbUserAgcyPaymentApplyResponseDetail> getDetailList() {
        if (StringUtils.isBlank(details)) {
            return null;
        }

        List<GcbUserAgcyPaymentApplyResponseDetail> detailList = new ArrayList<>();
        String[] detailLines = details.split(";");
        for (String line : detailLines) {
            String[] fields = line.split("\\|", -1);
            GcbUserAgcyPaymentApplyResponseDetail detail = new GcbUserAgcyPaymentApplyResponseDetail();
            detail.setRemitNo(trim(fields[0]));
            detail.setAmt(trim(fields[1]));
            detail.setBankId(trim(fields[2]));
            detail.setAcctType(trim(fields[3]));
            detail.setRemitType(fields[4]);
            detail.setAcctNo(trim(fields[5]));
            detail.setPayeeName(trim(fields[6]));
            detail.setIdType(trim(fields[7]));
            detail.setIdNo(trim(fields[8]));
            detail.setProvince(trim(fields[9]));
            detail.setCity(trim(fields[10]));
            detail.setBranchBankName(trim(fields[11]));
            detail.setPurpose(trim(fields[12]));
            detail.setRefNo(trim(fields[13]));
            detail.setExt1(trim(fields[14]));
            detail.setExt2(trim(fields[15]));
            detail.setUserId(trim(fields[16]));
            detail.setCnapsCode(trim(fields[17]));

            if (fields.length > 19) {
                detail.setErrorMsg(trim(fields[19]));
            } else if (fields.length > 18) {
                detail.setErrorMsg(trim(fields[18]));
            }

            detailList.add(detail);
        }

        return detailList;
    }

    private String trim(String val) {
        if (StringUtils.isBlank(val)) {
            return null;
        }

        return val.trim();
    }

    /**
     * 结果非明确失败，建议调用查询接口反查
     * @return
     */
    public PayoutRespStatus getRespStatus() {
        if (!isHttpStatusSuccess()) {
            return PayoutRespStatus.UNKNOWN;
        }

        if ("1".equals(status)) {
            return PayoutRespStatus.SUCCESS;
        }

        if ("2".equals(status)) {
            return PayoutRespStatus.FAILURE;
        }

        if ("3".equals(status)) {
            return PayoutRespStatus.PART_SUCCESS;
        }

        return PayoutRespStatus.UNKNOWN;
    }

    @Override
    public String toString() {
        return "GcbUserAgcyPaymentApplyResponse{" +
                "version='" + version + '\'' +
                ", signType='" + signType + '\'' +
                ", requestId='" + requestId + '\'' +
                ", requestTime='" + requestTime + '\'' +
                ", merchantAcctId='" + merchantAcctId + '\'' +
                ", terminalId='" + terminalId + '\'' +
                ", batchNo='" + batchNo + '\'' +
                ", payCur='" + payCur + '\'' +
                ", payTCnt='" + payTCnt + '\'' +
                ", payTAmt='" + payTAmt + '\'' +
                ", ignoreFlag='" + ignoreFlag + '\'' +
                ", purpose='" + purpose + '\'' +
                ", ext1='" + ext1 + '\'' +
                ", ext2='" + ext2 + '\'' +
                ", noticeUrl='" + noticeUrl + '\'' +
                ", realTimeNoticeUrl='" + realTimeNoticeUrl + '\'' +
                ", details='" + details + '\'' +
                ", status='" + status + '\'' +
                ", errorCode='" + errorCode + '\'' +
                ", errorMsg='" + errorMsg + '\'' +
                '}';
    }
}