package com.huifu.jh.payout.model.wrapper;

import com.huifu.jh.core.model.XmlRequestWrapper;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * @author fang.wei
 * @Description 商户代发请求报文封装类
 * @createTime 2021年10月20日 16:18:00
 */
@XmlRootElement(name = "REQUEST")
@XmlAccessorType(XmlAccessType.FIELD)
public class GcbAgcyPaymentApplyRequestWrapper implements XmlRequestWrapper<GcbAgcyPaymentApplyResponseWrapper> {

    @XmlElement(name = "GENERAL")
    private RequestHead head;

    @XmlElement(name = "PARAMS")
    private RequestParam params;

    public RequestHead getHead() {
        return head;
    }

    public void setHead(RequestHead head) {
        this.head = head;
    }

    public RequestParam getParams() {
        return params;
    }

    public void setParams(RequestParam params) {
        this.params = params;
    }

    public static Builder custom() {
        return new GcbAgcyPaymentApplyRequestWrapper.Builder();
    }

    public static class Builder {

        private String merchantId;
        private String terminalId;
        private String productType;
        private String version;
        private String trxType;
        private String batchNo;
        private String requestTime;
        private String payCur;
        private String payTotalCnt;
        private String payTotalAmt;
        private String purpose;
        private String ext1;
        private String ext2;
        private String resultUrl;
        private String reviewUrl;
        private String details;

        public Builder setMerchantId(String merchantId) {
            this.merchantId = merchantId;
            return this;
        }

        public Builder setTerminalId(String terminalId) {
            this.terminalId = terminalId;
            return this;
        }

        public Builder setProductType(String productType) {
            this.productType = productType;
            return this;
        }

        public Builder setVersion(String version) {
            this.version = version;
            return this;
        }

        public Builder setTrxType(String trxType) {
            this.trxType = trxType;
            return this;
        }

        public Builder setBatchNo(String batchNo) {
            this.batchNo = batchNo;
            return this;
        }

        public Builder setRequestTime(String requestTime) {
            this.requestTime = requestTime;
            return this;
        }

        public Builder setPayCur(String payCur) {
            this.payCur = payCur;
            return this;
        }

        public Builder setPayTotalCnt(String payTotalCnt) {
            this.payTotalCnt = payTotalCnt;
            return this;
        }

        public Builder setPayTotalAmt(String payTotalAmt) {
            this.payTotalAmt = payTotalAmt;
            return this;
        }

        public Builder setPurpose(String purpose) {
            this.purpose = purpose;
            return this;
        }

        public Builder setExt1(String ext1) {
            this.ext1 = ext1;
            return this;
        }

        public Builder setExt2(String ext2) {
            this.ext2 = ext2;
            return this;
        }

        public Builder setResultUrl(String resultUrl) {
            this.resultUrl = resultUrl;
            return this;
        }

        public Builder setReviewUrl(String reviewUrl) {
            this.reviewUrl = reviewUrl;
            return this;
        }

        public Builder setDetails(String details) {
            this.details = details;
            return this;
        }

        public GcbAgcyPaymentApplyRequestWrapper build() {
            GcbAgcyPaymentApplyRequestWrapper wrapper = new GcbAgcyPaymentApplyRequestWrapper();
            wrapper.setHead(new RequestHead(merchantId, terminalId, productType, version, trxType));
            wrapper.setParams(new RequestParam(batchNo, requestTime, payCur, payTotalCnt, payTotalAmt, purpose, ext1, ext2, resultUrl, reviewUrl, details));
            return wrapper;
        }
    }

    @Override
    public Class<GcbAgcyPaymentApplyResponseWrapper> getResponseWrapperClass() {
        return GcbAgcyPaymentApplyResponseWrapper.class;
    }

    @XmlAccessorType(XmlAccessType.FIELD)
    static class RequestHead {

        public RequestHead(String merchantId, String terminalId, String productType, String version, String trxType) {
            this.merchantId = merchantId;
            this.terminalId = terminalId;
            this.productType = productType;
            this.version = version;
            this.trxType = trxType;
        }

        @XmlElement(name = "MERCHANTID")
        private String merchantId;

        @XmlElement(name = "TERMINALID")
        private String terminalId;

        @XmlElement(name = "PRODUCTTYPE")
        private String productType;

        @XmlElement(name = "VERSION")
        private String version;

        @XmlElement(name = "TRXTYPE")
        private String trxType;

        public String getProductType() {
            return productType;
        }

        public void setProductType(String productType) {
            this.productType = productType;
        }

        public String getVersion() {
            return version;
        }

        public void setVersion(String version) {
            this.version = version;
        }

        public String getTrxType() {
            return trxType;
        }

        public void setTrxType(String trxType) {
            this.trxType = trxType;
        }

        public String getMerchantId() {
            return merchantId;
        }

        public void setMerchantId(String merchantId) {
            this.merchantId = merchantId;
        }

        public String getTerminalId() {
            return terminalId;
        }

        public void setTerminalId(String terminalId) {
            this.terminalId = terminalId;
        }
    }

    @XmlAccessorType(XmlAccessType.FIELD)
    static class RequestParam {

        public RequestParam(String batchNo, String requestTime, String payCur, String payTotalCnt, String payTotalAmt, String purpose, String ext1, String ext2, String resultUrl, String reviewUrl, String details) {
            this.batchNo = batchNo;
            this.requestTime = requestTime;
            this.payCur = payCur;
            this.payTotalCnt = payTotalCnt;
            this.payTotalAmt = payTotalAmt;
            this.purpose = purpose;
            this.ext1 = ext1;
            this.ext2 = ext2;
            this.resultUrl = resultUrl;
            this.reviewUrl = reviewUrl;
            this.details = details;
        }

        @XmlElement(name = "BATCH_NO")
        private String batchNo;

        @XmlElement(name = "REQTIME")
        private String requestTime;

        @XmlElement(name = "PAY_CUR")
        private String payCur;

        @XmlElement(name = "PAY_TCNT")
        private String payTotalCnt;

        @XmlElement(name = "PAY_TAMT")
        private String payTotalAmt;

        @XmlElement(name = "PURPOSE")
        private String purpose;

        @XmlElement(name = "EXT1")
        private String ext1;

        @XmlElement(name = "EXT2")
        private String ext2;

        @XmlElement(name = "RESULT_URL")
        private String resultUrl;

        @XmlElement(name = "REVIEW_URL")
        private String reviewUrl;

        @XmlElement(name = "DETAILS")
        private String details;

        public String getBatchNo() {
            return batchNo;
        }

        public void setBatchNo(String batchNo) {
            this.batchNo = batchNo;
        }

        public String getRequestTime() {
            return requestTime;
        }

        public void setRequestTime(String requestTime) {
            this.requestTime = requestTime;
        }

        public String getPayTotalCnt() {
            return payTotalCnt;
        }

        public void setPayTotalCnt(String payTotalCnt) {
            this.payTotalCnt = payTotalCnt;
        }

        public String getPayTotalAmt() {
            return payTotalAmt;
        }

        public void setPayTotalAmt(String payTotalAmt) {
            this.payTotalAmt = payTotalAmt;
        }

        public String getPayCur() {
            return payCur;
        }

        public void setPayCur(String payCur) {
            this.payCur = payCur;
        }

        public String getPurpose() {
            return purpose;
        }

        public void setPurpose(String purpose) {
            this.purpose = purpose;
        }

        public String getExt1() {
            return ext1;
        }

        public void setExt1(String ext1) {
            this.ext1 = ext1;
        }

        public String getExt2() {
            return ext2;
        }

        public void setExt2(String ext2) {
            this.ext2 = ext2;
        }

        public String getResultUrl() {
            return resultUrl;
        }

        public void setResultUrl(String resultUrl) {
            this.resultUrl = resultUrl;
        }

        public String getReviewUrl() {
            return reviewUrl;
        }

        public void setReviewUrl(String reviewUrl) {
            this.reviewUrl = reviewUrl;
        }

        public String getDetails() {
            return details;
        }

        public void setDetails(String details) {
            this.details = details;
        }
    }

}
