package com.huifu.jh.payout.model.wrapper;

import com.huifu.jh.core.model.XmlResponseWrapper;
import com.huifu.jh.payout.model.GcbAgcyPaymentApplyResponse;
import com.huifu.jh.payout.model.GcbAgcyPaymentApplyResponseDetail;
import org.apache.commons.lang.StringUtils;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.ArrayList;
import java.util.List;

/**
 * @author fang.wei
 * @Description 商户代发响应报文封装类
 * @createTime 2021年10月20日 16:18:00
 */
@XmlRootElement(name = "RESPONSE")
@XmlAccessorType(XmlAccessType.FIELD)
public class GcbAgcyPaymentApplyResponseWrapper implements XmlResponseWrapper<GcbAgcyPaymentApplyResponse> {

    @XmlElement(name = "GENERAL")
    private ResponseHead head;

    @XmlElement(name = "PARAMS")
    private ResponseParam param;

    @Override
    public GcbAgcyPaymentApplyResponse toResponse() {
        GcbAgcyPaymentApplyResponse response = new GcbAgcyPaymentApplyResponse();
        response.setMerchantId(head.getMerchantId());
        response.setTerminalId(head.getTerminalId());
        response.setProductType(head.getProductType());
        response.setVersion(head.getVersion());
        response.setTrxType(head.getTrxType());
        response.setBatchNo(param.getBatchNo());
        response.setRequestTime(param.getRequestTime());
        response.setPayCur(param.getPayCur());
        response.setPayTotalCnt(param.getPayTotalCnt());
        response.setPayTotalAmt(param.getPayTotalAmt());
        response.setPurpose(param.getPurpose());
        response.setExt1(param.getExt1());
        response.setExt2(param.getExt2());
        response.setResultUrl(param.getResultUrl());
        response.setDetails(convertDetails(param.getDetails()));
        response.setStatus(param.getStatus());
        response.setErrorCode(param.getErrorCode());
        response.setErrorMsg(param.getErrorMsg());
        return response;
    }

    /**
     * 转换明细对象列表
     * @param details
     * @return
     */
    private List<GcbAgcyPaymentApplyResponseDetail> convertDetails(String details) {
        if (StringUtils.isBlank(details)) {
            return null;
        }

        List<GcbAgcyPaymentApplyResponseDetail> list = new ArrayList<>();
        String[] detailLines = details.split("\\\n");
        for (String line : detailLines) {
            String[] fields = line.split("\\|", -1);
            GcbAgcyPaymentApplyResponseDetail detail = new GcbAgcyPaymentApplyResponseDetail();
            detail.setRemitNo(trim(fields[0]));
            detail.setAmt(trim(fields[1]));
            detail.setBankId(trim(fields[2]));
            detail.setAcctType(trim(fields[3]));
            detail.setAcctNo(trim(fields[4]));
            detail.setPayeeName(trim(fields[5]));
            detail.setIdType(trim(fields[6]));
            detail.setIdNo(trim(fields[7]));
            detail.setProvince(trim(fields[8]));
            detail.setCity(trim(fields[9]));
            detail.setBranchBankName(trim(fields[10]));
            detail.setPurpose(trim(fields[11]));
            detail.setSellTrxIds(trim(fields[12]));
            detail.setExt1(trim(fields[13]));
            detail.setExt2(trim(fields[14]));
            detail.setCnapsCode(trim(fields[15]));
            detail.setRemark(trim(fields[16]));
            detail.setRemitType(fields[17]);

            if (fields.length > 18) {
                detail.setErrorMsg(trim(fields[18]));
            }

            list.add(detail);
        }

        return list;
    }

    private String trim(String val) {
        if (StringUtils.isBlank(val)) {
            return null;
        }

        return val.trim();
    }

    public ResponseHead getHead() {
        return head;
    }

    public void setHead(ResponseHead head) {
        this.head = head;
    }

    public ResponseParam getParam() {
        return param;
    }

    public void setParam(ResponseParam param) {
        this.param = param;
    }

    @XmlAccessorType(XmlAccessType.FIELD)
    static class ResponseHead {

        @XmlElement(name = "MERCHANTID")
        private String merchantId;

        @XmlElement(name = "TERMINALID")
        private String terminalId;

        @XmlElement(name = "PRODUCTTYPE")
        private String productType;

        @XmlElement(name = "VERSION")
        private String version;

        @XmlElement(name = "TRXTYPE")
        private String trxType;

        public String getProductType() {
            return productType;
        }

        public void setProductType(String productType) {
            this.productType = productType;
        }

        public String getVersion() {
            return version;
        }

        public void setVersion(String version) {
            this.version = version;
        }

        public String getTrxType() {
            return trxType;
        }

        public void setTrxType(String trxType) {
            this.trxType = trxType;
        }

        public String getMerchantId() {
            return merchantId;
        }

        public void setMerchantId(String merchantId) {
            this.merchantId = merchantId;
        }

        public String getTerminalId() {
            return terminalId;
        }

        public void setTerminalId(String terminalId) {
            this.terminalId = terminalId;
        }
    }

    @XmlAccessorType(XmlAccessType.FIELD)
    static class ResponseParam {

        @XmlElement(name = "BATCH_NO")
        private String batchNo;

        @XmlElement(name = "REQTIME")
        private String requestTime;

        @XmlElement(name = "PAY_CUR")
        private String payCur;

        @XmlElement(name = "PAY_TCNT")
        private String payTotalCnt;

        @XmlElement(name = "PAY_TAMT")
        private String payTotalAmt;

        @XmlElement(name = "PURPOSE")
        private String purpose;

        @XmlElement(name = "EXT1")
        private String ext1;

        @XmlElement(name = "EXT2")
        private String ext2;

        @XmlElement(name = "RESULT_URL")
        private String resultUrl;

        @XmlElement(name = "DETAILS")
        private String details;

        @XmlElement(name = "STATUS")
        private String status;

        @XmlElement(name = "ERRERCODE")
        private String errorCode;

        @XmlElement(name = "ERRERMSG")
        private String errorMsg;

        public String getBatchNo() {
            return batchNo;
        }

        public void setBatchNo(String batchNo) {
            this.batchNo = batchNo;
        }

        public String getRequestTime() {
            return requestTime;
        }

        public void setRequestTime(String requestTime) {
            this.requestTime = requestTime;
        }

        public String getPayTotalCnt() {
            return payTotalCnt;
        }

        public void setPayTotalCnt(String payTotalCnt) {
            this.payTotalCnt = payTotalCnt;
        }

        public String getPayTotalAmt() {
            return payTotalAmt;
        }

        public void setPayTotalAmt(String payTotalAmt) {
            this.payTotalAmt = payTotalAmt;
        }

        public String getPayCur() {
            return payCur;
        }

        public void setPayCur(String payCur) {
            this.payCur = payCur;
        }

        public String getPurpose() {
            return purpose;
        }

        public void setPurpose(String purpose) {
            this.purpose = purpose;
        }

        public String getExt1() {
            return ext1;
        }

        public void setExt1(String ext1) {
            this.ext1 = ext1;
        }

        public String getExt2() {
            return ext2;
        }

        public void setExt2(String ext2) {
            this.ext2 = ext2;
        }

        public String getResultUrl() {
            return resultUrl;
        }

        public void setResultUrl(String resultUrl) {
            this.resultUrl = resultUrl;
        }

        public String getDetails() {
            return details;
        }

        public void setDetails(String details) {
            this.details = details;
        }

        public String getStatus() {
            return status;
        }

        public void setStatus(String status) {
            this.status = status;
        }

        public String getErrorCode() {
            return errorCode;
        }

        public void setErrorCode(String errorCode) {
            this.errorCode = errorCode;
        }

        public String getErrorMsg() {
            return errorMsg;
        }

        public void setErrorMsg(String errorMsg) {
            this.errorMsg = errorMsg;
        }
    }
}