package com.huifu.jh.payout.model.wrapper;

import com.huifu.jh.core.model.XmlCallbackResponseWrapper;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * @author fang.wei
 * @Description 商户代发异步通知应答报文封装类
 * @createTime 2021年10月25日 12:38:00
 */
@XmlRootElement(name = "RESPONSE")
@XmlAccessorType(XmlAccessType.FIELD)
public class GcbAgcyPaymentResultResponseWrapper implements XmlCallbackResponseWrapper {

    @XmlElement(name = "GENERAL")
    private ResponseHead head;

    @XmlElement(name = "PARAMS")
    private ResponseParam param;

    public static GcbAgcyPaymentResultResponseWrapper.Builder custom() {
        return new Builder();
    }

    public ResponseHead getHead() {
        return head;
    }

    public void setHead(ResponseHead head) {
        this.head = head;
    }

    public ResponseParam getParam() {
        return param;
    }

    public void setParam(ResponseParam param) {
        this.param = param;
    }

    public static class Builder {

        private String merchantId;
        private String terminalId;
        private String productType;
        private String version;
        private String trxType;
        private String result;

        public Builder setMerchantId(String merchantId) {
            this.merchantId = merchantId;
            return this;
        }

        public Builder setTerminalId(String terminalId) {
            this.terminalId = terminalId;
            return this;
        }

        public Builder setProductType(String productType) {
            this.productType = productType;
            return this;
        }

        public Builder setVersion(String version) {
            this.version = version;
            return this;
        }

        public Builder setTrxType(String trxType) {
            this.trxType = trxType;
            return this;
        }

        public Builder setResult(String result) {
            this.result = result;
            return this;
        }

        public GcbAgcyPaymentResultResponseWrapper build() {
            GcbAgcyPaymentResultResponseWrapper wrapper = new GcbAgcyPaymentResultResponseWrapper();
            wrapper.setHead(new ResponseHead(merchantId, terminalId, productType, version, trxType));
            wrapper.setParam(new ResponseParam(result));
            return wrapper;
        }
    }

    @XmlAccessorType(XmlAccessType.FIELD)
    static class ResponseHead {

        @XmlElement(name = "MERCHANTID")
        private String merchantId;

        @XmlElement(name = "TERMINALID")
        private String terminalId;

        @XmlElement(name = "PRODUCTTYPE")
        private String productType;

        @XmlElement(name = "VERSION")
        private String version;

        @XmlElement(name = "TRXTYPE")
        private String trxType;

        public ResponseHead(String merchantId, String terminalId, String productType, String version, String trxType) {
            this.merchantId = merchantId;
            this.terminalId = terminalId;
            this.productType = productType;
            this.version = version;
            this.trxType = trxType;
        }

        public String getProductType() {
            return productType;
        }

        public void setProductType(String productType) {
            this.productType = productType;
        }

        public String getVersion() {
            return version;
        }

        public void setVersion(String version) {
            this.version = version;
        }

        public String getTrxType() {
            return trxType;
        }

        public void setTrxType(String trxType) {
            this.trxType = trxType;
        }

        public String getMerchantId() {
            return merchantId;
        }

        public void setMerchantId(String merchantId) {
            this.merchantId = merchantId;
        }

        public String getTerminalId() {
            return terminalId;
        }

        public void setTerminalId(String terminalId) {
            this.terminalId = terminalId;
        }
    }

    @XmlAccessorType(XmlAccessType.FIELD)
    static class ResponseParam {

        public ResponseParam(String result) {
            this.result = result;
        }

        @XmlElement(name = "RESULT")
        private String result;

        public String getResult() {
            return result;
        }

        public void setResult(String result) {
            this.result = result;
        }
    }

}